==> scribe-pen-3.3.11-sources.jar: org/smallmind/scribe/pen/adapter/LoggerAdapter.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.scribe.pen.adapter;

import org.smallmind.scribe.pen.Appender;
import org.smallmind.scribe.pen.Enhancer;
import org.smallmind.scribe.pen.Filter;
import org.smallmind.scribe.pen.Level;

public interface LoggerAdapter {

  String getName ();

  ParameterAdapter getParameterAdapter ();

  boolean getAutoFillLogicalContext ();

  void setAutoFillLogicalContext (boolean autoFillLogicalContext);

  void addFilter (Filter filter);

  void clearFilters ();

  void addAppender (Appender appender);

  void clearAppenders ();

  void addEnhancer (Enhancer enhancer);

  void clearEnhancers ();

  Level getLevel ();

  void setLevel (Level level);

  void logMessage (Level level, Throwable throwable, String message, Object... args);

  void logMessage (Level level, Throwable throwable, Object object);
}

==> scribe-pen-5.7.0-sources.jar: org/smallmind/scribe/pen/adapter/LoggerAdapter.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020 David Berkman
 *
 * This file is part of the SmallMind Code Project.
 *
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 *
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * ...or...
 *
 * 2) The terms of the Apache License, Version 2.0.
 *
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 *
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.scribe.pen.adapter;

import java.util.function.Supplier;
import org.smallmind.scribe.pen.Appender;
import org.smallmind.scribe.pen.Enhancer;
import org.smallmind.scribe.pen.Filter;
import org.smallmind.scribe.pen.Level;

public interface LoggerAdapter {

  String getName ();

  ParameterAdapter getParameterAdapter ();

  boolean getAutoFillLoggerContext ();

  void setAutoFillLoggerContext (boolean autoFillLoggerContext);

  void addFilter (Filter filter);

  void clearFilters ();

  void addAppender (Appender appender);

  void clearAppenders ();

  void addEnhancer (Enhancer enhancer);

  void clearEnhancers ();

  Level getLevel ();

  void setLevel (Level level);

  void logMessage (Level level, Throwable throwable, String message, Object... args);

  void logMessage (Level level, Throwable throwable, Object object);

  void logMessage (Level level, Throwable throwable, Supplier<String> supplier);
}
